@@ -6,9 +6,9 @@ use warnings;
 use App::TestOnTap::Util qw(slashify ensureArray);
 use App::TestOnTap::OrderStrategy;
 use App::TestOnTap::ExecMap;
-use App::TestOnTap::_dbgvars;
 
 use Config::Std;
+use File::Spec;
 use Grep::Query;
 use UUID::Tiny qw(:std);
 
@@ -17,13 +17,15 @@ use UUID::Tiny qw(:std);
 sub new
 {
 	my $class = shift;
-	my $path = shift;
-	my $userExecMapFile = shift;
+	my $suiteRoot = shift;
+	my $userCfgFile = shift;
+	my $ignoreDeps = shift;
+
+	my $configFile = slashify(File::Spec->rel2abs($userCfgFile || "$suiteRoot/" . getName()));
+	die("Missing configuration file '$configFile'\n") unless -f $configFile;
 
-	my $configFilePath = -f $path ? $path : slashify("$path/" . getName());
-	
 	my $self = bless({}, $class);
-	$self->__readCfgFile($configFilePath, $userExecMapFile);
+	$self->__readCfgFile($configFile, $ignoreDeps);
 
 	return $self;
 }
@@ -34,27 +36,20 @@ sub new
 sub __readCfgFile
 {
 	my $self = shift;
-	my $configFilePath = $App::TestOnTap::_dbgvars::FORCED_CONFIG_FILE || shift;
-	my $userExecMapFile = shift;
+	my $configFile = shift;
+	my $ignoreDeps = shift;
 	
-	my $cfg;
+	read_config($configFile, my $cfg);
 	
-	if (!$App::TestOnTap::_dbgvars::IGNORE_CONFIG_FILE)
-	{
-		die("Missing configuration '$configFilePath'\n") unless -e $configFilePath;
-		
-		read_config($configFilePath, $cfg);
-		
-		# this looks weird, I know - see https://rt.cpan.org/Public/Bug/Display.html?id=56862
-		#
-		# I seem to hit the problem with "Warning: Name "Config::Std::Hash::DEMOLISH" used only once..."
-		# when running a Par::Packer binary but not when as a 'normal' script.
-		#
-		# The below incantation seem to get rid of that, at least for now. Let's see if it reappears... 
-		#
-		my $dummy = *Config::Std::Hash::DEMOLISH;
-		$dummy = *Config::Std::Hash::DEMOLISH;
-	}
+	# this looks weird, I know - see https://rt.cpan.org/Public/Bug/Display.html?id=56862
+	#
+	# I seem to hit the problem with "Warning: Name "Config::Std::Hash::DEMOLISH" used only once..."
+	# when running a Par::Packer binary but not when as a 'normal' script.
+	#
+	# The below incantation seem to get rid of that, at least for now. Let's see if it reappears... 
+	#
+	my $dummy = *Config::Std::Hash::DEMOLISH;
+	$dummy = *Config::Std::Hash::DEMOLISH;
 	
 	# pick the necessities from the blank section
 	#
@@ -110,10 +105,10 @@ sub __readCfgFile
 	
 	# set up the execmap, possibly as a delegate from a user defined one 
 	#
-	$self->{execmap} = App::TestOnTap::ExecMap->new($userExecMapFile, $cfg->{EXECMAP});
+	$self->{execmap} = App::TestOnTap::ExecMap->new($cfg);
 
 	my %depRules;
-	if (!$App::TestOnTap::_dbgvars::IGNORE_DEPENDENCIES)
+	if (!$ignoreDeps)
 	{
 		# find all dependency sections
 		#
@@ -139,7 +134,7 @@ sub __readCfgFile
 			my %validSectionKeys = map { $_ => 1 } qw(match dependson);
 			foreach my $key (keys(%{$cfg->{$depRuleSectionName}}))
 			{
-				warn("Unknown key '$key' in section '[$depRuleSectionName]'\n") unless exists($validSectionKeys{$key});
+				warn("WARNING: Unknown key '$key' in section '[$depRuleSectionName]'\n") unless exists($validSectionKeys{$key});
 			}
 		}
 	}
@@ -147,7 +142,7 @@ sub __readCfgFile
 	
 	# finally check the config for unknown sections/keys...
 	#
-	my @validSections = (qr/^$/, qr/^DEPENDENCY\s/, qr/^EXECMAP$/);
+	my @validSections = (qr/^$/, qr/^DEPENDENCY\s/, qr/^EXECMAP\s+[^\s]+\s*$/);
 	foreach my $section (sort(keys(%$cfg)))
 	{
 		my $knownSection = 0;
@@ -159,21 +154,16 @@ sub __readCfgFile
 				last;
 			}
 		}
-		warn("Unknown section: '[$section]'\n") unless $knownSection;
+		warn("WARNING: Unknown section: '[$section]'\n") unless $knownSection;
 	}
 
-	my %validBlankSectionKeys = map { $_ => 1 } qw(id skip preprocess postprocess parallelizable order);
+	my %validBlankSectionKeys = map { $_ => 1 } qw(id skip preprocess postprocess parallelizable order execmap);
 	foreach my $key (sort(keys(%$blankSection)))
 	{
-		warn("Unknown key '$key' in default section\n") unless exists($validBlankSectionKeys{$key});
+		warn("WARNING: Unknown key '$key' in default section\n") unless exists($validBlankSectionKeys{$key});
 	}
-}
-
-sub getName
-{
-	# works as both class/instance/sub...
-	#
-	return $App::TestOnTap::_dbgvars::CONFIG_FILE_NAME;
+	
+	$self->{rawcfg} = { %$cfg };
 }
 
 sub getId
@@ -194,6 +184,13 @@ sub skip
 			: 0;
 }
 
+sub getName
+{
+       # works as both class/instance/sub...
+       #
+       return 'config.testontap';
+}
+
 sub getOrderStrategy
 {
 	my $self = shift;
@@ -249,6 +246,13 @@ sub getExecMapping
 	return $self->{execmap}->getMapping($testName);	
 }
 
+sub getRawCfg
+{
+	my $self = shift;
+
+	return $self->{rawcfg};	
+}
+
 sub getDependencyRuleNames
 {
 	my $self = shift;
